% USB remote programming
% - EOS (end of string) character and mode must be set properly, see below.
% - Commands and queries must be terminated by '\n'.

% USB/USB-TMC initiation 
obj = visa('ni', 'USB0::0x03EB::0xAFFF::151-212300000-0000::INSTR');
fopen(obj);

% Default EOS (end of string) character is '\n' which is fine. But default
% EOS mode is none, such that the EOS character won't be sent. Enable the
% EOS character for both writing and reading by selecting 'read&write' at
% the EOSmode property.
set(obj, 'EOSMode', 'read&write');

idn = query(obj, '*IDN?\n');
fprintf('*IDN? response: %s', idn);

fprintf(obj, 'FREQ:STAR %s MHz\n', '20'); 

%Set the START frequency
fprintf(obj, 'FREQ:STAR %s MHz\n', '20'); 

%Set the STOP frequency
fprintf(obj, 'FREQUENCY:STOP %s MHz\n', '300');

%Set RF ON
fprintf(obj, 'OUTP ON\n');

% Synchronize (wait until all previous commands have been executed
% completely)
query(obj, '*OPC?\n');

pause(1);

%Set RF OFF
fprintf(obj, 'OUTPUT OFF\n');

%Set the POWER 
fprintf(obj, 'POW 3 dBm\n');

fclose(obj);